### TEST

##### Introduction

TEST.py will launch all the tests for the different images, results

##### Protocol Parameters

- test_list is a list parameter with a default value of [{'name': 'image_io_test', 'options': None}, {'name': 'global_variable_test', 'options': None}], it lists all the test functions

##### Examples


##### Author(s)

